Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: chrome/browser/resources/settings/device_page/pointers.js

Issue 2110833003: MD Settings: Add mouse settings, update pointer settings (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@PointersFake
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/settings/device_page/pointers.js
diff --git a/chrome/browser/resources/settings/device_page/touchpad.js b/chrome/browser/resources/settings/device_page/pointers.js
similarity index 54%
rename from chrome/browser/resources/settings/device_page/touchpad.js
rename to chrome/browser/resources/settings/device_page/pointers.js
index 16ee984f64dd28f12e04d3ff51560e5cd7dfc6c3..c1fcecbb171f0ab40fd56caabf186350572feb70 100644
--- a/chrome/browser/resources/settings/device_page/touchpad.js
+++ b/chrome/browser/resources/settings/device_page/pointers.js
@@ -4,10 +4,14 @@
/**
* @fileoverview
* 'settings-touchpad' is the settings subpage with touchpad settings.
*/
Polymer({
- is: 'settings-touchpad',
+ is: 'settings-pointers',
+
+ behaviors: [
+ I18nBehavior,
+ ],
properties: {
/** Preferences state. */
@@ -15,6 +19,16 @@ Polymer({
type: Object,
notify: true,
},
+
+ hasMouse: {
+ type: Boolean,
+ value: false,
+ },
+
+ hasTouchpad: {
+ type: Boolean,
+ value: false,
+ },
},
/**
@@ -25,4 +39,9 @@ Polymer({
onLearnMoreLinkActivated_: function(e) {
settings.DevicePageBrowserProxyImpl.getInstance().handleLinkEvent(e);
},
+
+ // Mouse and touchpad sections are only subsections if they are both present.
+ getSectionClass_: function(hasMouse, hasTouchpad) {
+ return hasMouse && hasTouchpad ? 'subsection' : '';
+ },
});

Powered by Google App Engine
@@ -4,10 +4,14 @@
/**
* @fileoverview
- * 'settings-touchpad' is the settings subpage with touchpad settings.
+ * 'settings-pointers' is the settings subpage with mouse and touchpad settings.
*/
Polymer({
This is Rietveld 408576698